@@ -1,4 +1,4 @@
-from .app.main import *
+from .main import *
 from .app.cli import *
 
 __all__ = ['run', 'cli']
