@@ -1,7 +1,7 @@
 #!/usr/bin/env python3.11
 
 import click
-from ..app.main import run
+from main import run
 
 
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
